"use client"

import Link from "next/link"
import { BookOpen, FileText, Award, Clock, Users, Play, Smartphone } from "lucide-react"
import Image from "next/image"

export default function LandingPage() {
  return (
    <div className="min-h-screen bg-white">
      {/* Hero Section */}
      <section className="bg-gradient-to-r from-[#3d53b6] to-[#1da7f3] py-20 px-4">
        <div className="container mx-auto flex flex-col md:flex-row items-center">
          <div className="md:w-1/2 mb-10 md:mb-0">
            <h1 className="text-4xl md:text-5xl font-bold text-white mb-4">
              Réussissez votre examen du Code de la Route
            </h1>
            <p className="text-xl text-white mb-8">
              Apprenez efficacement avec notre plateforme interactive. Cours théoriques, exercices pratiques et examens
              blancs pour vous préparer au mieux.
            </p>
            <div className="flex flex-col sm:flex-row gap-4">
              <Link
                href="/auth/register"
                className="bg-white text-[#3d53b6] hover:bg-[#1da7f3]/10 py-3 px-8 rounded-full font-semibold text-center"
              >
                Commencer gratuitement
              </Link>
              <Link
                href="/auth/login"
                className="bg-transparent border-2 border-white text-white hover:bg-white hover:text-[#3d53b6] py-3 px-8 rounded-full font-semibold text-center"
              >
                Découvrir
              </Link>
            </div>
          </div>
          <div className="md:w-1/2 flex justify-center">
            <div className="relative w-full max-w-md h-80 bg-white rounded-lg shadow-xl overflow-hidden">
              <Image
                src="/placeholder.svg?height=400&width=600"
                alt="Apprentissage du code de la route"
                width={600}
                height={400}
                className="object-cover"
              />
              <div className="absolute inset-0 bg-black bg-opacity-20 flex items-center justify-center">
                <div className="bg-white rounded-full p-4 shadow-lg">
                  <Play className="h-10 w-10 text-[#3d53b6]" />
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      {/* Statistiques */}
      <section className="py-16 bg-gray-50">
        <div className="container mx-auto px-4">
          <div className="grid grid-cols-1 md:grid-cols-3 gap-8 text-center">
            <div className="bg-white p-8 rounded-lg shadow-md">
              <div className="text-4xl font-bold text-[#3d53b6] mb-2">+1000</div>
              <p className="text-gray-700">Questions d'entraînement</p>
            </div>
            <div className="bg-white p-8 rounded-lg shadow-md">
              <div className="text-4xl font-bold text-[#3d53b6] mb-2">95%</div>
              <p className="text-gray-700">Taux de réussite</p>
            </div>
            <div className="bg-white p-8 rounded-lg shadow-md">
              <div className="text-4xl font-bold text-[#3d53b6] mb-2">24/7</div>
              <p className="text-gray-700">Accès illimité</p>
            </div>
          </div>
        </div>
      </section>

      {/* Comment ça marche - Vidéo YouTube */}
      <section className="py-16 px-4" id="comment-ca-marche">
        <div className="container mx-auto text-center">
          <h2 className="text-3xl font-bold mb-2">Comment ça marche</h2>
          <p className="text-xl text-gray-600 mb-12 max-w-3xl mx-auto">
            Découvrez notre plateforme en vidéo et apprenez à utiliser toutes nos fonctionnalités pour réussir votre
            examen.
          </p>

          <div className="relative w-full max-w-4xl mx-auto aspect-video bg-gray-200 rounded-xl overflow-hidden shadow-lg">
            {/* Remplacez l'URL par votre vidéo YouTube */}
            <iframe
              className="absolute inset-0 w-full h-full"
              src="https://www.youtube.com/embed/votre-id-video"
              title="Comment utiliser notre plateforme de Code de la Route"
              frameBorder="0"
              allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
              allowFullScreen
            ></iframe>
          </div>
        </div>
      </section>

      {/* Fonctionnalités */}
      <section className="py-16 px-4 bg-gray-50" id="fonctionnalites">
        <div className="container mx-auto">
          <h2 className="text-3xl font-bold text-center mb-2">Nos fonctionnalités</h2>
          <p className="text-xl text-gray-600 text-center mb-12 max-w-3xl mx-auto">
            Tout ce dont vous avez besoin pour réussir votre examen du code de la route.
          </p>

          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            <div className="bg-white p-8 rounded-lg shadow-md">
              <div className="bg-[#1da7f3] w-16 h-16 rounded-full flex items-center justify-center mb-6">
                <BookOpen className="h-8 w-8 text-white" />
              </div>
              <h3 className="text-xl font-bold mb-3">Cours théoriques</h3>
              <p className="text-gray-600">
                Des leçons complètes et détaillées sur tous les aspects du code de la route, mises à jour régulièrement.
              </p>
            </div>

            <div className="bg-white p-8 rounded-lg shadow-md">
              <div className="bg-[#1da7f3] w-16 h-16 rounded-full flex items-center justify-center mb-6">
                <FileText className="h-8 w-8 text-white" />
              </div>
              <h3 className="text-xl font-bold mb-3">Exercices pratiques</h3>
              <p className="text-gray-600">
                Des exercices interactifs pour tester vos connaissances après chaque leçon et renforcer votre
                apprentissage.
              </p>
            </div>

            <div className="bg-white p-8 rounded-lg shadow-md">
              <div className="bg-[#1da7f3] w-16 h-16 rounded-full flex items-center justify-center mb-6">
                <Award className="h-8 w-8 text-white" />
              </div>
              <h3 className="text-xl font-bold mb-3">Examens blancs</h3>
              <p className="text-gray-600">
                Des examens complets de 40 questions dans les conditions réelles pour vous préparer parfaitement.
              </p>
            </div>

            <div className="bg-white p-8 rounded-lg shadow-md">
              <div className="bg-[#1da7f3] w-16 h-16 rounded-full flex items-center justify-center mb-6">
                <Smartphone className="h-8 w-8 text-white" />
              </div>
              <h3 className="text-xl font-bold mb-3">Accessible partout</h3>
              <p className="text-gray-600">
                Apprenez où que vous soyez, sur tous vos appareils : ordinateur, tablette ou smartphone.
              </p>
            </div>

            <div className="bg-white p-8 rounded-lg shadow-md">
              <div className="bg-[#1da7f3] w-16 h-16 rounded-full flex items-center justify-center mb-6">
                <Clock className="h-8 w-8 text-white" />
              </div>
              <h3 className="text-xl font-bold mb-3">Suivi de progression</h3>
              <p className="text-gray-600">
                Visualisez votre progression et identifiez les domaines à améliorer grâce à des statistiques détaillées.
              </p>
            </div>

            <div className="bg-white p-8 rounded-lg shadow-md">
              <div className="bg-[#1da7f3] w-16 h-16 rounded-full flex items-center justify-center mb-6">
                <Users className="h-8 w-8 text-white" />
              </div>
              <h3 className="text-xl font-bold mb-3">Communauté d'entraide</h3>
              <p className="text-gray-600">
                Échangez avec d'autres apprenants et posez vos questions à nos moniteurs professionnels.
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* How It Works Section */}
      <section className="py-20">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl font-bold text-center mb-16">Comment ça marche ?</h2>

          <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
            <div className="text-center">
              <div className="bg-[#3d53b6] text-white w-12 h-12 rounded-full flex items-center justify-center mx-auto mb-6 text-xl font-bold">
                1
              </div>
              <h3 className="text-xl font-bold mb-4">Inscrivez-vous</h3>
              <p className="text-gray-600">
                Créez votre compte gratuitement en quelques secondes pour commencer votre apprentissage.
              </p>
            </div>

            <div className="text-center">
              <div className="bg-[#3d53b6] text-white w-12 h-12 rounded-full flex items-center justify-center mx-auto mb-6 text-xl font-bold">
                2
              </div>
              <h3 className="text-xl font-bold mb-4">Étudiez les leçons</h3>
              <p className="text-gray-600">Parcourez nos leçons interactives et apprenez à votre rythme.</p>
            </div>

            <div className="text-center">
              <div className="bg-[#3d53b6] text-white w-12 h-12 rounded-full flex items-center justify-center mx-auto mb-6 text-xl font-bold">
                3
              </div>
              <h3 className="text-xl font-bold mb-4">Testez vos connaissances</h3>
              <p className="text-gray-600">
                Pratiquez avec des exercices et des examens blancs pour valider vos acquis.
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Testimonials Section */}
      <section className="py-20 bg-gray-50">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl font-bold text-center mb-16">Ce que disent nos utilisateurs</h2>

          <div className="grid grid-cols-1 md:grid-cols-3 gap-8">
            <div className="bg-white p-8 rounded-xl shadow-md">
              <div className="flex items-center mb-4">
                <div className="bg-[#1da7f3] w-12 h-12 rounded-full flex items-center justify-center mr-4">
                  <span className="text-white font-bold">S</span>
                </div>
                <div>
                  <h4 className="font-bold">Sophie D.</h4>
                  <p className="text-gray-500 text-sm">Bruxelles</p>
                </div>
              </div>
              <p className="text-gray-600">
                "Grâce à cette plateforme, j'ai réussi mon examen théorique du premier coup ! Les exercices sont
                vraiment similaires à ceux de l'examen officiel."
              </p>
            </div>

            <div className="bg-white p-8 rounded-xl shadow-md">
              <div className="flex items-center mb-4">
                <div className="bg-[#1da7f3] w-12 h-12 rounded-full flex items-center justify-center mr-4">
                  <span className="text-white font-bold">T</span>
                </div>
                <div>
                  <h4 className="font-bold">Thomas L.</h4>
                  <p className="text-gray-500 text-sm">Liège</p>
                </div>
              </div>
              <p className="text-gray-600">
                "Le suivi de progression est génial, j'ai pu facilement identifier mes points faibles et me concentrer
                dessus. Interface très intuitive !"
              </p>
            </div>

            <div className="bg-white p-8 rounded-xl shadow-md">
              <div className="flex items-center mb-4">
                <div className="bg-[#1da7f3] w-12 h-12 rounded-full flex items-center justify-center mr-4">
                  <span className="text-white font-bold">M</span>
                </div>
                <div>
                  <h4 className="font-bold">Marie V.</h4>
                  <p className="text-gray-500 text-sm">Namur</p>
                </div>
              </div>
              <p className="text-gray-600">
                "J'ai pu étudier à mon rythme, même avec mon emploi du temps chargé. Les explications sont claires et
                les illustrations très utiles."
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* FAQ Section */}
      <section className="py-20">
        <div className="container mx-auto px-4">
          <h2 className="text-3xl font-bold text-center mb-16">Questions fréquentes</h2>

          <div className="grid grid-cols-1 md:grid-cols-2 gap-8">
            <div className="bg-white p-6 rounded-lg shadow-md">
              <h3 className="text-xl font-bold mb-3">Combien de temps faut-il pour se préparer à l'examen ?</h3>
              <p className="text-gray-600">
                Cela varie selon chaque personne, mais la plupart de nos utilisateurs se sentent prêts pour l'examen
                après 2 à 4 semaines d'étude régulière.
              </p>
            </div>

            <div className="bg-white p-6 rounded-lg shadow-md">
              <h3 className="text-xl font-bold mb-3">Les cours sont-ils à jour avec la législation actuelle ?</h3>
              <p className="text-gray-600">
                Oui, tous nos contenus sont régulièrement mis à jour pour refléter les dernières modifications du code
                de la route belge.
              </p>
            </div>

            <div className="bg-white p-6 rounded-lg shadow-md">
              <h3 className="text-xl font-bold mb-3">Puis-je accéder aux cours sur mon téléphone ?</h3>
              <p className="text-gray-600">
                Absolument ! Notre plateforme est entièrement responsive et s'adapte à tous les appareils : ordinateurs,
                tablettes et smartphones.
              </p>
            </div>

            <div className="bg-white p-6 rounded-lg shadow-md">
              <h3 className="text-xl font-bold mb-3">Que comprend l'abonnement premium ?</h3>
              <p className="text-gray-600">
                L'abonnement premium vous donne accès à des fonctionnalités exclusives comme des examens blancs
                illimités, des statistiques détaillées, des fiches de révision téléchargeables et un accès prioritaire à
                nos moniteurs pour poser vos questions.
              </p>
            </div>

            <div className="bg-white p-6 rounded-lg shadow-md">
              <h3 className="text-xl font-bold mb-3">Puis-je annuler mon abonnement à tout moment ?</h3>
              <p className="text-gray-600">
                Oui, vous pouvez annuler votre abonnement à tout moment depuis votre espace personnel. Vous continuerez
                à bénéficier des avantages premium jusqu'à la fin de la période payée.
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="py-20 bg-[#3d53b6] text-white">
        <div className="container mx-auto px-4 text-center">
          <h2 className="text-3xl md:text-4xl font-bold mb-8">Prêt à commencer votre apprentissage ?</h2>
          <p className="text-xl mb-10 max-w-3xl mx-auto">
            Rejoignez des milliers d'apprenants qui ont déjà réussi leur examen grâce à notre plateforme.
          </p>
          <Link
            href="/auth/register"
            className="bg-white text-[#1da7f3] hover:bg-[#1da7f3]/10 py-3 px-10 rounded-full font-bold text-lg inline-block"
          >
            S'inscrire gratuitement
          </Link>
        </div>
      </section>
    </div>
  )
}
